# Pintes
*An amalgamation of horror.*
Pintes is a tool made in Python that allows users to develop static HTML pages with ease.

## Why?
- For the actual tool, I have no idea. I had an idea and I worked on it.
- For the name, I also have no idea.

## How?
Pintes internally uses a list that the tag create functions append to. This list is then joined and written to a file after the necessary tags are added.

## Usage
As of 0.1:PRERELEASE, Pintes is not on PyPI. And since I don't understand how to use setup.py, you'll have to clone the repository and use the `pintes.py` file as a module.
Use the `demo.py` file as a reference to how to use Pintes.
